@@ -5,12 +5,12 @@ built_modules = list(name for name in
 shiboken_library_soversion = str(6.8)
 pyside_library_soversion = str(6.8)
 
-version = "6.8.1.1"
-version_info = (6, 8, 1.1, "", "")
+version = "6.8.2"
+version_info = (6, 8, 2, "", "")
 
-__build_date__ = '2025-01-02T21:25:24+00:00'
-__build_commit_date__ = '2025-01-02T21:12:23+00:00'
-__build_commit_hash__ = '83e5a2e78ecafc1daaed77000f2df77a983ad4ae'
+__build_date__ = '2025-02-02T09:17:37+00:00'
+__build_commit_date__ = '2025-02-02T08:48:09+00:00'
+__build_commit_hash__ = 'de9375cf0d39bceb7bcf00c2909ad29c1d91ed3b'
 
 
 
